@@ -9,6 +9,10 @@ from pathlib import Path
 
 class Config:
 
+    _context = {
+        "env": os.environ,
+    }
+
     def __init__(self, config, templates):
         self._config = config
         self._cli_templates = self.load_templates(templates)
@@ -48,12 +52,22 @@ class Config:
 
         print(flags)
         for flag in flags:
-            flag_vals.append("{flag} {value}".format(flag=flag, value=flags[flag]))
+            val = flags[flag]
+            if not val:
+                val = ''
+            flag_vals.append("{flag} {value}".format(flag=flag, value=val))
 
         return self._format_config(' '.join(flag_vals), 'curl_flags')
 
+    def get_body(self):
+        body = self.get('body', None)
+        if isinstance(body, dict):
+            return json.dumps(body)
+        else:
+            return body.strip()
+
     def _format_config(self, value, key):
-        merged_template = {**self._config_templates, **self._cli_templates}
+        merged_template = {**self._context, **self._config_templates, **self._cli_templates}
 
         try:
             return value.format(**merged_template)
@@ -120,7 +134,7 @@ def main():
         args.template_vars
     )
 
-    body = config.get('body', '').strip()
+    body = config.get_body()
     headers = config.get_headers()
     curl_flags = config.get_curl_flags()
 
